@@ -6,62 +6,99 @@ package Alien::FLTK;
     use File::Spec::Functions qw[catdir rel2abs canonpath];
     use File::Basename;
     use File::Find qw[find];
-    our $VERSION_BASE = 0; our $FLTK_SVN = 6841; our $UNSTABLE_RELEASE = 16; our $VERSION = sprintf('%d.%05d' . ($UNSTABLE_RELEASE ? '_%03d' : ''), $VERSION_BASE, $FLTK_SVN, $UNSTABLE_RELEASE);
-    sub revision { return $FLTK_SVN; }
     my $_config = eval do { local $/; <DATA> }
         or warn
         "Couldn't load Alien::FLTK configuration data: $@\n Using defaults";
     close DATA;
+    sub new { return bless \$|, shift; }
     sub config { return $_config; }
+    our $VERSION_BASE = 0; our $FLTK_SVN = 6879; our $UNSTABLE_RELEASE = 3; our $VERSION = sprintf('%d.%05d' . ($UNSTABLE_RELEASE ? '_%03d' : ''), $VERSION_BASE, $FLTK_SVN, $UNSTABLE_RELEASE);
+    sub revision { return $FLTK_SVN; }
+    sub branch   { return $_config->{'fltk_branch'} }
 
     sub include_path {
+        my ($self) = @_;
         my @include = map { -d $_ ? $_ : () } (
-                 rel2abs(catdir(qw[blib arch Alien FLTK include])),
-                 rel2abs(catdir(dirname(rel2abs(__FILE__)), qw[FLTK include]))
+                                  rel2abs(
+                                      catdir(qw[blib arch Alien FLTK include],
+                                             'fltk-' . $self->branch
+                                      )
+                                  ),
+                                  rel2abs(catdir(dirname(rel2abs(__FILE__)),
+                                                 qw[FLTK include],
+                                                 'fltk-' . $self->branch
+                                          )
+                                  )
         );
         return $include[0];
     }
 
     sub library_path {
+        my ($self) = @_;
         my @libs = map { -d $_ ? $_ : () } (
-                    rel2abs(catdir(qw[blib arch Alien FLTK libs])),
-                    rel2abs(catdir(dirname(rel2abs(__FILE__)), qw[FLTK libs]))
+                                     rel2abs(
+                                         catdir(qw[blib arch Alien FLTK libs],
+                                                'fltk-' . $self->branch
+                                         )
+                                     ),
+                                     rel2abs(
+                                            catdir(dirname(rel2abs(__FILE__)),
+                                                   qw[FLTK libs],
+                                                   'fltk-' . $self->branch
+                                            )
+                                     )
         );
         return $libs[0];
     }
 
     sub cflags {
-        return $_config->{'cxxflags'} . ' -I' . Alien::FLTK->include_path();
+        return $_config->{'cxxflags'} . ' -I' . shift->include_path();
     }
-    sub cxxflags { return Alien::FLTK->cflags() . ' -Wno-non-virtual-dtor'; }
+    sub cxxflags { return shift->cflags() . ' -Wno-non-virtual-dtor'; }
 
     sub ldflags {    # XXX - Cache this
         my ($self, @args) = @_;
 
         #
-        my $libdir = Alien::FLTK->library_path();
+        my $libdir = shift->library_path();
 
         # Calculate needed libraries
         my $SHAREDSUFFIX = $Config{'_a'};
-        my $LDSTATIC     = "-L$libdir $libdir/libfltk2$SHAREDSUFFIX "
-            . $_config->{'ldflags'};
+        my $LDSTATIC     = sprintf '-L%s %s/libfltk%s%s %s',
+            $libdir, $libdir, ($self->branch eq '1.3.x' ? '' : '2'),
+            $SHAREDSUFFIX, $_config->{'ldflags'};
         my $LDFLAGS = "-L$libdir " . $_config->{'ldflags'};
-        my $LIBS    = "$libdir/libfltk2$SHAREDSUFFIX";
+        my $LIBS = sprintf '%s/libfltk%s%s', $libdir,
+            ($self->branch eq '1.3.x' ? '' : '2'),
+            $SHAREDSUFFIX;
         if (grep {m[forms]} @args) {
-            $LDFLAGS  = "-lfltk2_forms $LDFLAGS";
-            $LDSTATIC = "$libdir/libfltk2_forms$SHAREDSUFFIX $LDSTATIC";
-            $LIBS     = "$LIBS $libdir/libfltk2_forms$SHAREDSUFFIX";
+            $LDFLAGS = sprintf '-lfltk%s_forms %s',
+                ($self->branch eq '1.3.x' ? '' : '2'), $LDFLAGS;
+            $LDSTATIC = sprintf '$libdir/libfltk%s_forms%s %s',
+                $libdir, ($self->branch eq '1.3.x' ? '' : '2'), $SHAREDSUFFIX,
+                $$LDSTATIC;
+            $LIBS = sprintf '%s %s/libfltk%s_forms%s',
+                $LIBS, $libdir, ($self->branch eq '1.3.x' ? '' : '2'),
+                $SHAREDSUFFIX;
         }
         if ((grep {m[gl]} @args) && $_config->{'GL'}) {
             my $LIBGL = $_config->{'GL'};
-            $LDFLAGS  = "-lfltk2_gl $LIBGL $LDFLAGS";
-            $LDSTATIC = "$libdir/libfltk2_gl$SHAREDSUFFIX $LIBGL $LDSTATIC";
-            $LIBS     = "$LIBS $libdir/libfltk2_gl$SHAREDSUFFIX";
+            $LDFLAGS = sprintf '-lfltk%s_gl %s %s',
+                ($self->branch eq '1.3.x' ? '' : '2'),
+                $LIBGL, $LDFLAGS;
+            $LDSTATIC = sprintf '%s/libfltk%s_gl%s %s %s',
+                $libdir, ($self->branch eq '1.3.x' ? '' : '2'),
+                $SHAREDSUFFIX, $LIBGL, $LDSTATIC;
+            $LIBS = sprintf '%s %s/libfltk%s_gl%s',
+                $LIBS, $libdir,
+                ($self->branch eq '1.3.x' ? '' : '2'),
+                $SHAREDSUFFIX;
         }
         if (grep {m[images]} @args) {
             $LDFLAGS  = $_config->{'image_flags'} . " $LDFLAGS";
-            $LDSTATIC = "$libdir/libfltk2_images$SHAREDSUFFIX $LDSTATIC "
-                . $_config->{'image_flags'};
+            $LDSTATIC = sprintf '%s/libfltk%s_images%s %s %s',
+                $libdir, ($self->branch eq '1.3.x' ? '' : '2'),
+                $SHAREDSUFFIX, $LDSTATIC, $_config->{'image_flags'};
         }
         return (
              ((grep {m[static]} @args) ? $LDSTATIC : $LDFLAGS) . ' -lsupc++');
@@ -93,6 +130,7 @@ C<2.0.x> branch of the FLTK GUI toolkit.
     use Alien::FLTK;
     use ExtUtils::CBuilder;
     my $CC     = ExtUtils::CBuilder->new();
+    my $AF     = $AF->new();
     my $source = 'hello_world.cxx';
     open(my $FH, '>', $source) || die '...';
     syswrite($FH, <<'') || die '...'; close $FH;
@@ -114,44 +152,55 @@ C<2.0.x> branch of the FLTK GUI toolkit.
       }
 
     my $obj = $CC->compile(source               => $source,
-                           extra_compiler_flags => Alien::FLTK->cxxflags());
+                           extra_compiler_flags => $AF->cxxflags());
     my $exe = $CC->link_executable(
                                   objects            => $obj,
-                                  extra_linker_flags => Alien::FLTK->ldflags()
+                                  extra_linker_flags => $AF->ldflags()
     );
     print system('./' . $exe) ? 'Aww...' : 'Yay!';
     END { unlink grep defined, $source, $obj, $exe; }
 
+=head1 Constructor
+
+There are no per-object configuration options as of this version, but there
+may be in the future, so any new code using L<Alien::FLTK|Alien::FLTK> should
+create objects with the C<new> constructor.
+
+    my $AF = Alien::FLTK->new( );
+
 =head1 Methods
 
+After creating a new L<Alien::FLTK|Alien::FLTK> object, use the following
+methods to gather information:
+
 =head2 C<include_path>
 
-    my $include_path = Alien::FLTK->include_path;
+    my $include_path = $AF->include_path( );
 
 Returns the location of the headers installed during the build process.
 
 =head2 C<library_path>
 
-    my $include_path = Alien::FLTK->library_path;
+    my $include_path = $AF->library_path( );
 
 Returns the location of the private libraries we made and installed
 during the build process.
 
 =head2 C<cflags>
 
-    my $cflags = Alien::FLTK->cflags;
+    my $cflags = $AF->cflags( );
 
 Returns additional C compiler flags to be used.
 
 =head2 C<cxxflags>
 
-    my $cxxflags = Alien::FLTK->cxxflags;
+    my $cxxflags = $AF->cxxflags( );
 
 Returns additional flags to be used to when compiling C++ using FLTK.
 
 =head2 C<ldflags>
 
-    my $ldflags = Alien::FLTK->ldflags(qw[gl images]);
+    my $ldflags = $AF->ldflags( qw[gl images] );
 
 Returns additional linker flags to be used. This method can automatically add
 appropriate flags based on how you plan on linking to fltk. Acceptable
@@ -163,7 +212,8 @@ arguments are:
 
 Returns flags to link against a static FLTK library.
 
-I<FLTK's license allows static linking, btw.>
+FLTK's license allows static linking, but L<Alien::FLTK|Alien::FLTK> does not
+build static libs. ...yet.
 
 =item C<gl>
 
@@ -192,17 +242,67 @@ Include flags to use FLTK's forms compatibility layer.
 
 =head2 C<revision>
 
-    my $revision = Alien::FLTK->revision;
+    my $revision = $AF->revision( );
 
-Returns the SVN revision number of the source L<C<Alien::FLTK>|Alien::FLTK>
+Returns the SVN revision number of the source L<Alien::FLTK|Alien::FLTK>
 was built with.
 
-=head1 Bugs
+=head2 C<capabilities>
 
-Numerous, I'm sure.
+    my $caps = $AF->capabilities( );
+
+Returns a list of capabilities supported by your L<Alien::FLTK|Alien::FLTK>
+installation. This list can be handed directly to
+L<C<ldflags( )>|Alien::FLTK/ldflags>.
+
+=head2 C<config>
+
+    my $configuration = $AF->config( );
+
+Returns a hashref containing the raw configuration data collected during
+build. This would be helpful when reporting bugs, etc.
 
 =head1 Notes
 
+=head2 Requirements
+
+Prerequisites differ by system...
+
+=over
+
+=item Win32
+
+The fltk2 libs and L<Alien::FLTK|Alien::FLTK> both build right out of the box
+with MinGW. Further testing is needed for other setups.
+
+=item X11/*nix
+
+X11-based systems require several development packages. On Debian, these may
+be installed with...
+
+  > sudo apt-get install libx11-dev
+  > sudo apt-get install libxi-dev
+  > sudo apt-get install libxcursor-dev
+
+=item Darwin/OSX
+
+Uh, yeah, I have no idea.
+
+=back
+
+=head2 Installation
+
+Building the fltk libs requires a functioning C++ compiler, bash, and (to
+make life easy) a version of make.
+
+The distribution is based on L<Module::Build|Module::Build>, so use the
+following procedure:
+
+  > perl Build.PL
+  > ./Build
+  > ./Build test
+  > ./Build install
+
 =head2 Support Links
 
 =over
@@ -240,44 +340,15 @@ http://github.com/sanko/alien-fltk/ and you are invited to fork it.
 
 =back
 
-=head2 Requirements
-
-Once installed, L<Alien::FLTK> depends on:
-
-=over
-
-=item L<Config|Config>
-
-=item L<File::Spec::Functions>
-
-=item L<File::Basename>
-
-=item L<File::Find>
-
-=back
-
 =head2 Examples
 
 Please see the L<Synopsis|/"Synopsis"> and the files in the C</example/>.
 
-=head2 Installation
+=head2 Bugs
 
-Building the fltk2 libs requires a functioning C++ compiler, bash, and (to
-make life easy) a version of make.
+Numerous, I'm sure.
 
-The distribution is based on L<Module::Build|Module::Build>, so use the
-following procedure:
-
-  perl Build.PL
-  ./Build
-  ./Build test
-  ./Build install
-
-An attempt has been made to work around an incomplete set of build tools. This
-fallback requires L<ExtUtils::CBuilder|ExtUtils::CBuilder> and plenty of
-begging. Consider it alpha at best.
-
-=head1 To Do
+=head2 To Do
 
 Please see L<Alien::FLTK::Todo|Alien::FLTK::Todo>
 
@@ -313,11 +384,11 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-L<C<Alien::FLTK>|Alien::FLTK> is based in part on the work of the FLTK
-project. See http://www.fltk.org/.
+L<Alien::FLTK|Alien::FLTK> is based in part on the work of the FLTK project.
+See http://www.fltk.org/.
 
-=for git $Id: FLTK.pm e048451 2009-09-02 03:23:06Z sanko@cpan.org $
+=for git $Id: FLTK.pm 7ece19a 2009-10-08 04:09:32Z sanko@cpan.org $
 
 =cut
 __DATA__
-do{ my $x = { }; $x; }
\ No newline at end of file
+do{ my $x = { }; $x; }
